==> gm-1.6.3_Linux.tar.gz: gm-1.6.3_Linux/tests/gm_alarm.c <==
#include <stdio.h>
#include <signal.h>
#include "gm.h"

int sig_set;
int alarm_set;
unsigned long ones;
unsigned long hundreds;
unsigned long alarm_set_count;
unsigned long alarm_sig_count;

void sig_handler (int sig)
{
  sig_set = 1;
}

void callback (void* p)
{
  alarm_set = 0;
  alarm_sig_count++;
}

static int gm_alarm (int argc, char* argv[])
{
  struct gm_port* port;
  gm_status_t status;
  gm_alarm_t alarm;
  gm_recv_event_t* e;
  
  signal (SIGINT, sig_handler);

  gm_init ();
  status = gm_open (&port, 0, 2, "alarm",
		    (enum gm_api_version) GM_API_VERSION);
  if (status != GM_SUCCESS) {
    gm_perror ("could not open port", status);
    gm_exit (GM_FAILURE);
  }
  
  alarm_set_count = 0;
  alarm_sig_count = 0;
  sig_set = 0;
  alarm_set = 0;
  ones = 0;
  hundreds = 0;
  gm_initialize_alarm (&alarm);
  for (;;) {
    e = gm_receive (port);
    switch (gm_ntoh_u8 (e->recv.type)) {
    case GM_ALARM_EVENT:
      gm_unknown (port, e);
      break;
    default:
      gm_unknown (port, e);
      break;
    }
    if (!alarm_set) {
      gm_initialize_alarm (&alarm); 
      gm_set_alarm (port, &alarm, 1000, callback, NULL);
      alarm_set = 1;
      alarm_set_count++;
      ones++;
      if (ones == 100) {
	hundreds++;
	ones = 0;
	printf ("%lu alarms set/signaled.\n", hundreds * 100);
      }
    }
    if (sig_set) {
      break;
    }
  }

  printf ("Alarm set %lu time(s).\n", alarm_set_count);
  printf ("Alarm signaled %lu time(s).\n", alarm_sig_count);
  if (alarm_set) {
    gm_cancel_alarm (&alarm);
  }
  gm_close (port);
  gm_finalize ();
  return 0;
}

#define GM_MAIN gm_alarm
#include "gm_main.h"

==> gm-2.0.8_Linux.tar.gz: gm-2.0.8_Linux/tests/gm_alarm.c <==
#include <stdio.h>
#include <signal.h>
#include "gm.h"

int sig_set;
int alarm_set;
unsigned long ones;
unsigned long hundreds;
unsigned long alarm_set_count;
unsigned long alarm_sig_count;

static void sig_handler (int sig)
{
  sig_set = 1;
}

static void callback (void* p)
{
  printf ("in callback\n");
  alarm_set = 0;
  alarm_sig_count++;
}

static int gm_alarm (int argc, char* argv[])
{
  struct gm_port* port;
  gm_status_t status;
  gm_alarm_t alarm;
  gm_recv_event_t* e;
  
  signal (SIGINT, sig_handler);

  gm_init ();
  status = gm_open (&port, 0, 2, "alarm",
		    (enum gm_api_version) GM_API_VERSION);
  if (status != GM_SUCCESS) {
    gm_perror ("could not open port", status);
    gm_exit (GM_FAILURE);
  }
  
  alarm_set_count = 0;
  alarm_sig_count = 0;
  sig_set = 0;
  alarm_set = 0;
  ones = 0;
  hundreds = 0;
  gm_initialize_alarm (&alarm);
  for (;;) {
    e = gm_blocking_receive (port);
    switch (gm_ntoh_u8 (e->recv.type)) {
    case GM_ALARM_EVENT:
      gm_unknown (port, e);
      break;
    default:
      gm_unknown (port, e);
      break;
    }
    if (!alarm_set) {
      gm_initialize_alarm (&alarm); 
      gm_set_alarm (port, &alarm, 1000, callback, NULL);
      alarm_set = 1;
      alarm_set_count++;
      ones++;
      if (ones == 100) {
	hundreds++;
	ones = 0;
	printf ("%lu alarms set/signaled.\n", hundreds * 100);
      }
    }
    if (sig_set) {
      break;
    }
  }

  printf ("Alarm set %lu time(s).\n", alarm_set_count);
  printf ("Alarm signaled %lu time(s).\n", alarm_sig_count);
  if (alarm_set) {
    gm_cancel_alarm (&alarm);
  }
  gm_close (port);
  gm_finalize ();
  return 0;
}

#define GM_MAIN gm_alarm
#include "gm_main.h"
